clear all
close all
%%                 AD identification, Torsional Test                  %%

%%SINGLE DOF identification method in time domain
%%Input: Displacement and force time history from wind tunnel testing
%%Output: Aerodynamic derivatives

%Import of data from torsional section tests, 1 wind speed, 7 frequencies

%Imported data:
%WindV - wind velocity
%rr - displacment time history
%omega - motion frequency
%SteadyTime - time vector
%Q - recorded self-excited forces

%Get section properties
SectionNumber=1;
load('SectionProperties.mat');
B=SectionsBHL(SectionNumber,1);
L=SectionsBHL(SectionNumber,3);

freq=[0.5, 0.8, 1.1, 1.4, 1.7, 2, 2.5]; %Frequencies of motion

for i=1:length(freq)
load(['day 3Self-excited forces 4.9883wind spped ' num2str(freq(i)) 'Hz.mat'])
if i==1 
qstore=zeros(9000,3,length(freq));
rstore=zeros(9000,3,length(freq));
end
qstore(:,:,i)=Q(1:9000,:); %Store forces in matrix
rstore(:,:,i)=rr(1:9000,:); %Store forces in matrix

% Make 0 mean forces
for j=1:3
    clear meanvector
    meanvector=ones(9000,1);
if mean(qstore(:,j,i))>0
    meanvector=mean(qstore(:,j,i)).*meanvector;
    qstore(:,j,i)=qstore(:,j,i)-abs(meanvector);
elseif mean(qstore(:,j,i))<0
    meanvector=mean(qstore(:,j,i)).*meanvector;
    qstore(:,j,i)=qstore(:,j,i)+abs(meanvector);
end
end

end
omega=(2*pi).*freq; %Calculations in radians

%Get time increment
dt=SteadyTime(20)-SteadyTime(19);

%redefining displacment time history vectors. Row 1: y-dir, row 2: z-dir,
%row 3: angle
dth=zeros(3,9000,length(freq));

for i=1:length(freq)
    for j=1:3
        dth(j,:,i)=rstore(:,j,i);
    end
end
N=length(dth);

%Defining aerodynamic derivative vectors
P=zeros(6,length(freq));
H=zeros(6,length(freq));
A=zeros(6,length(freq));
P_star=zeros(6,length(freq));
H_star=zeros(6,length(freq));
A_star=zeros(6,length(freq));

%Create velocity and displacment matrix. 
%[(y-dir velocity) (y-dir displacement) (z-dir velocity z-dir displacment) (torsion velocity torsion displacement)]

X_U_i=zeros(N,2*3,j);
for j=1:length(freq)
    for i=1:3
        for n=1:N-2
         X_U_i(n+1,2*i-1,j)=(dth(i,n+2,j)-dth(i,n,j))/(2*dt);
         X_U_i(n,2*i,j)=dth(i,n,j);
        end
    end
end

%Calculation flutter derivatives from each test at different wind
%velocities



%Calculate reduced frequency and velocity in each direction
VV_red=WindV./(omega*B);    %Reduced wind velocity 
K_y=(B.*omega)./WindV;      %Reduced horizontal circular frequency 
K_z=(B.*omega)./WindV;       %Reduced vertical circular frequency 
K_theta=(B.*omega)./WindV;   %Reduced torsional circular frequency 

    %Calculate aerodynamic derivative at each frequency point
for j=1:length(freq)
    clear Q_se_U_j D_i

    %Load recorded forces
    Q_se_U_j=qstore(:,:,j);
    
%Equivalent aerodynamic derivatives:
    D_i=(X_U_i(:,(2*3-1:2*3),j)'*X_U_i(:,(2*3-1:2*3),j))\(X_U_i(:,(2*3-1:2*3),j)'*Q_se_U_j);

%Put the equivalent aerodynamic derivatives in correct vector:
        P(2,j)=D_i(1,1);P(3,j)=D_i(2,1);
        H(2,j)=D_i(1,2);H(3,j)=D_i(2,2);
        A(2,j)=D_i(1,3);A(3,j)=D_i(2,3);

%Create matrix relationship between equivalent and true aerodynamic
%derivatives
RelMatDrag=(0.5*rho*(WindV^2)*B).*[K_y(j)/WindV 0 0 0 0 0; 
                                    0 K_theta(j)*B/WindV 0 0 0 0; 
                                    0 0 K_theta(j)^2 0 0 0; 
                                    0 0 0 (K_y(j)^2)/B 0 0;
                                    0 0 0 0 K_z(j)/WindV 0;
                                    0 0 0 0 0 (K_z(j)^2)/B];
 
RelMatLift=(0.5*rho*(WindV^2)*B).*[K_z(j)/WindV 0 0 0 0 0; 
                                    0 K_theta(j)*B/WindV 0 0 0 0; 
                                    0 0 K_theta(j)^2 0 0 0; 
                                    0 0 0 (K_z(j)^2)/B 0 0;
                                    0 0 0 0 K_y(j)/WindV 0;
                                    0 0 0 0 0 (K_y(j)^2)/B];
 
RelMatMoment=(0.5*rho*(WindV^2)*B^2).*[K_z(j)/WindV 0 0 0 0 0; 
                                        0 K_theta(j)*B/WindV 0 0 0 0; 
                                        0 0 K_theta(j)^2 0 0 0; 
                                        0 0 0 (K_z(j)^2)/B 0 0;
                                        0 0 0 0 K_y(j)/WindV 0;
                                        0 0 0 0 0 (K_y(j)^2)/B];

P_star(2,j)=(1/L)*P(2,j)/RelMatDrag(2,2);
P_star(3,j)=(1/L)*P(3,j)/RelMatDrag(3,3);
H_star(2,j)=(1/L)*H(2,j)/RelMatLift(2,2);
H_star(3,j)=(1/L)*H(3,j)/RelMatLift(3,3);
A_star(2,j)=(1/L)*A(2,j)/RelMatMoment(2,2);
A_star(3,j)=(1/L)*A(3,j)/RelMatMoment(3,3);
end

    %Plotting
    VV_red=(2*pi).*VV_red; %Plotting in Hz
        
        
     x = [VV_red 0];
        yP2 = [P_star(2,:) 0];
        yP3 = [P_star(3,:) 0];
        yH2 = [H_star(2,:) 0];
        yH3 = [H_star(3,:) 0];
        yA2 = [A_star(2,:) 0];
        yA3 = [A_star(3,:) 0];

        pP2 = polyfit(x,yP2,3);
        pP3 = polyfit(x,yP3,3);
        pH2 = polyfit(x,yH2,3);
        pH3 = polyfit(x,yH3,3);
        pA2 = polyfit(x,yA2,3);
        pA3 = polyfit(x,yA3,3);

        x1 = linspace(0,ceil(max(VV_red)));
        y1pP2 = polyval(pP2,x1);
        y1pP3 = polyval(pP3,x1);
        y1pA2 = polyval(pA2,x1);
        y1pA3 = polyval(pA3,x1);
        y1pH2 = polyval(pH2,x1);
        y1pH3 = polyval(pH3,x1);

        h30=figure(30);
        subplot(3,2,1)
        plot(x,yP2,'o')
        hold on
        plot(x1,y1pP2)
        title('P^{*}_2')
        hold off
        
        subplot(3,2,2)
        plot(x,yP3,'o')
        hold on
        plot(x1,y1pP3)
        title('P^{*}_3')
        hold off

        subplot(3,2,3)
        plot(x,yH2,'o')
        hold on
        plot(x1,y1pH2)
        title('H^{*}_2')
        hold off
        
        subplot(3,2,4)
        plot(x,yH3,'o')
        hold on
        plot(x1,y1pH3)
        title('H^{*}_3')
        hold off

        subplot(3,2,5)
        plot(x,yA2,'o')
        hold on
        plot(x1,y1pA2)
        title('A^{*}_2')
        hold off

        subplot(3,2,6)
        plot(x,yA3,'o')
        hold on
        plot(x1,y1pA3)
        title('A^{*}_3')
        hold off

        suptitle('Torsional test, Section ?')
    
% %Printing of figures to latex image folder:
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_horizontal.jpg')
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_vertical.jpg')   
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_torsional.jpg')   
% 
% print(h10,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_horizontal.jpg')
% print(h20,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_vertical.jpg')
% print(h30,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_torsional.jpg')

% Saving ADs to matrix.

%ADs = cat(3,H_star,A_star,P_star);
%save('ADs','ADs')

DataPath=['C:\Users\svend\OneDrive for Business\Masteroppgave\Fra Vindtunneltesting\Wind tunnel process data\Compare\twin2torsion'];
MatSavePath=[DataPath '.mat'];

%Redefining variables and storing for further use
% x_tw2t=x;
% yP2_tw2t=yP2;
% yP3_tw2t=yP3;
% yH2_tw2t=yH2;
% yH3_tw2t=yH3;
% yA2_tw2t=yA2;
% yA3_tw2t=yA3;
% 
% save(MatSavePath,'x_tw2t','yP2_tw2t','yP3_tw2t','yH2_tw2t','yH3_tw2t','yA2_tw2t','yA3_tw2t')


