clear all
close all
%%                 AD identification, Vertical Test                  %%

%%SINGLE DOF identification method in time domain
%%Input: Displacement and force time history from wind tunnel testing
%%Output: Aerodynamic derivatives

%Import of data from vertical section tests, 1 wind speed, 7 frequencies

%Imported data:
%WindV - wind velocity
%SteadyTime - time vector
%rr - displacment time history
%Q - recorded self-excited forces

freq=[0.5, 0.8, 1.1, 1.4, 1.7, 2, 2.5];
rho=1.17;

SectionNumber=1; %Choose section number
load('SectionProperties.mat');
B=SectionsBHL(SectionNumber,1);
L=SectionsBHL(SectionNumber,3);

for i=1:length(freq)
load(['day 3Self-excited forces 5.0651wind spped ' num2str(freq(i)) 'Hz.mat'])
clear meanforce
if i==1 
qstore=zeros(9000,3,length(freq));
rstore=zeros(9000,3,length(freq));
end
qstore(:,:,i)=Q(1:9000,:);
rstore(:,:,i)=rr(1:9000,:);

% Make 0 means
for j=1:3
    clear meanvector rmeanvector
    meanvector=ones(9000,1);
if mean(qstore(:,j,i))>0
    meanvector=mean(qstore(:,j,i)).*meanvector;
    qstore(:,j,i)=qstore(:,j,i)-abs(meanvector);
elseif mean(qstore(:,j,i))<0
    meanvector=mean(qstore(:,j,i)).*meanvector;
    qstore(:,j,i)=qstore(:,j,i)+abs(meanvector);
end
end

end
omega=(2*pi).*freq;

dt=SteadyTime(20)-SteadyTime(19); 

%redefining displacment time history vectors. Row 1: y-dir, row 2: z-dir,
%row 3: angle
dth=zeros(3,9000,length(freq));

for i=1:length(freq)
    for j=1:3
        dth(j,:,i)=rstore(:,j,i);
    end
end
N=length(dth);

%Defining aerodynamic derivative vectors
P=zeros(6,length(freq));
H=zeros(6,length(freq));
A=zeros(6,length(freq));
P_star=zeros(6,length(freq));
H_star=zeros(6,length(freq));
A_star=zeros(6,length(freq));

%Create velocity and displacment matrix. 
%[(y-dir velocity) (y-dir displacement) (z-dir velocity z-dir displacment) (torsion velocity torsion displacement)]

X_U_i=zeros(N,2*3,j);
for j=1:length(freq)
    for i=1:3
        for n=1:N-2
         X_U_i(n+1,2*i-1,j)=(dth(i,n+2,j)-dth(i,n,j))/(2*dt);
         X_U_i(n,2*i,j)=dth(i,n,j);
        end
    end
end

%Calculation flutter derivatives from each test at different wind
%velocities

%Calculate reduced frequency and velocity in each direction
VV_red=WindV./(omega*B);    %Reduced wind velocity 
K_y=(B.*omega)./WindV;      %Reduced horizontal circular frequency 
K_z=(B.*omega)./WindV;       %Reduced vertical circular frequency 
K_theta=(B.*omega)./WindV;   %Reduced torsional circular frequency 

%Calculate aerodynamic derivative at each frequency point
for j=1:length(freq)
    clear Q_se_U_j D_i

     %Load recorded forces
    Q_se_U_j=qstore(:,:,j);
    
    
%Equivalent aerodynamic derivatives:
    D_i=(X_U_i(:,(2*2-1:2*2),j)'*X_U_i(:,(2*2-1:2*2),j))\(X_U_i(:,(2*2-1:2*2),j)'*Q_se_U_j);

%Put the equivalent aerodynamic derivatives in correct vector:
        
        P(5,j)=D_i(1,1);P(6,j)=D_i(2,1);
        H(1,j)=D_i(1,2);H(4,j)=D_i(2,2);
        A(1,j)=D_i(1,3);A(4,j)=D_i(2,3); 

%Create matrix relationship between equivalent and true aerodynamic
%derivatives
RelMatDrag=(0.5*rho*(WindV^2)*B).*[K_y(j)/WindV 0 0 0 0 0; 
                                    0 K_theta(j)*B/WindV 0 0 0 0; 
                                    0 0 K_theta(j)^2 0 0 0; 
                                    0 0 0 (K_y(j)^2)/B 0 0;
                                    0 0 0 0 K_z(j)/WindV 0;
                                    0 0 0 0 0 (K_z(j)^2)/B];
 
RelMatLift=(0.5*rho*(WindV^2)*B).*[K_z(j)/WindV 0 0 0 0 0; 
                                    0 K_theta(j)*B/WindV 0 0 0 0; 
                                    0 0 K_theta(j)^2 0 0 0; 
                                    0 0 0 (K_z(j)^2)/B 0 0;
                                    0 0 0 0 K_y(j)/WindV 0;
                                    0 0 0 0 0 (K_y(j)^2)/B];
 
RelMatMoment=(0.5*rho*(WindV^2)*B^2).*[K_z(j)/WindV 0 0 0 0 0; 
                                        0 K_theta(j)*B/WindV 0 0 0 0; 
                                        0 0 K_theta(j)^2 0 0 0; 
                                        0 0 0 (K_z(j)^2)/B 0 0;
                                        0 0 0 0 K_y(j)/WindV 0;
                                        0 0 0 0 0 (K_y(j)^2)/B];

%Only vertical motion (per unit length of section)
P_star(5,j)=(1/L)*P(5,j)/RelMatDrag(5,5);
P_star(6,j)=(1/L)*P(6,j)/RelMatDrag(6,6);
H_star(1,j)=(1/L)*H(1,j)/RelMatLift(1,1);
H_star(4,j)=(1/L)*H(4,j)/RelMatLift(4,4);
A_star(1,j)=(1/L)*A(1,j)/RelMatMoment(1,1);
A_star(4,j)=(1/L)*A(4,j)/RelMatMoment(4,4);
end
   
%Plotting 
VV_red=(2*pi).*VV_red; %Plotting in Hz

    x = [VV_red 0];
    
        yP5 = [P_star(5,:) 0];
        yP6 = [P_star(6,:) 0];
        yH1 = [H_star(1,:) 0];
        yH4 = [H_star(4,:) 0];
        yA1 = [A_star(1,:) 0];
        yA4 = [A_star(4,:) 0];
        
        pP5 = polyfit(x,yP5,3);
        pP6 = polyfit(x,yP6,3);
        pH1 = polyfit(x,yH1,3);
        pH4 = polyfit(x,yH4,3);
        pA1 = polyfit(x,yA1,3);
        pA4 = polyfit(x,yA4,3);

        x1 = linspace(0,ceil(max(VV_red)));
        y1pP5 = polyval(pP5,x1);
        y1pP6 = polyval(pP6,x1);
        y1pA1 = polyval(pA1,x1);
        y1pA4 = polyval(pA4,x1);
        y1pH1 = polyval(pH1,x1);
        y1pH4 = polyval(pH4,x1);

        h20=figure(20);
        
        subplot(3,2,1)
        plot(x,yP5,'o')
        hold on
        plot(x1,y1pP5)
        title('P^{*}_5')
        hold off
        xlab=xlabel('[$\frac{V_{w}}{B_{m}f_{n}}$]');
        set(xlab,'Interpreter','Latex','Position',get(xlab,'Position') - [-1.8 -0.08 0])
     
        
        subplot(3,2,2)
        plot(x,yP6,'o')
        hold on
        plot(x1,y1pP6)
        title('P^{*}_6')
        hold off
        xlab=xlabel('[$\frac{V_{w}}{B_{m}f_{n}}$]');
        set(xlab,'Interpreter','Latex','Position',get(xlab,'Position') - [-1.8 -0.08 0])
        
        subplot(3,2,3)
        plot(x,yH1,'o')
        hold on
        plot(x1,y1pH1)
        title('H^{*}_1')
        hold off
        xlab=xlabel('[$\frac{V_{w}}{B_{m}f_{n}}$]');
        set(xlab,'Interpreter','Latex','Position',get(xlab,'Position') - [-1.8 -0.08 0])

        subplot(3,2,4)
        plot(x,yH4,'o')
        hold on
        plot(x1,y1pH4)
        title('H^{*}_4')
        hold off
        xlab=xlabel('[$\frac{V_{w}}{B_{m}f_{n}}$]');
        set(xlab,'Interpreter','Latex','Position',get(xlab,'Position') - [-1.8 -0.08 0])
        
        subplot(3,2,5)
        plot(x,yA1,'o')
        hold on
        plot(x1,y1pA1)
        title('A^{*}_1')
        hold off
        xlab=xlabel('[$\frac{V_{w}}{B_{m}f_{n}}$]');
        set(xlab,'Interpreter','Latex','Position',get(xlab,'Position') - [-1.8 -0.08 0])

        subplot(3,2,6)
        plot(x,yA4,'o')
        hold on
        plot(x1,y1pA4)
        title('A^{*}_4')
        hold off
        xlab=xlabel('[$\frac{V_{w}}{B_{m}f_{n}}$]');
        set(xlab,'Interpreter','Latex','Position',get(xlab,'Position') - [-1.8 -0.5 0])

        suptitle('ADs from vertical test')
       
       
%Change name!        
% %Printing of figures to latex image folder:
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_horizontal.jpg')
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_vertical.jpg')   
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_torsional.jpg')   
% 
% print(h10,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_horizontal.jpg')
% print(h20,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_vertical.jpg')
% print(h30,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_torsional.jpg')

% Saving ADs to matrix.

%ADs = cat(3,H_star,A_star,P_star);
%save('ADs','ADs')

% DataPath=['C:\Users\svend\OneDrive for Business\Masteroppgave\Fra Vindtunneltesting\Wind tunnel process data\Compare\twin2vertical'];
% MatSavePath=[DataPath '.mat'];
% 
% %Redefining variables and storing for further use
% x_tw2v=x;
% yP5_tw2v=yP5;
% yP6_tw2v=yP6;
% yH1_tw2v=yH1;
% yH4_tw2v=yH4;
% yA1_tw2v=yA1;
% yA4_tw2v=yA4;
% 
% save(MatSavePath,'x_tw2v','yP5_tw2v','yP6_tw2v','yH1_tw2v','yH4_tw2v','yA1_tw2v','yA4_tw2v')