%Abaqus model of rectangular model section
%GEOMETRY
clear all
n_el=40; %Number of elements
l_girder=2.68; %[m]
l_el_girder=l_girder/n_el; %[m]
l_endpipe=0.015; %[m]
l_el_endpipe=l_endpipe; %[m]

%Node coordinates
node_girder=zeros(n_el+1,4);
node_girder(:,1)=101:(100+n_el+1);
node_girder(:,2)=0:l_el_girder:l_girder;

node_endpipe1=[1 -l_endpipe 0 0];
node_endpipe2=[2 (l_girder+l_el_endpipe) 0 0];


%Elements
elGirder=zeros(n_el,3);
elGirder(:,1)=101:(100+n_el);
elGirder(:,2)=elGirder(:,1);
elGirder(:,3)=elGirder(:,1)+1;
elEndpipe1=[1 1 node_girder(1,1)];
elEndpipe2=[2 node_girder(n_el+1,1) 2];
            
%%Create file
clc
fid = fopen('rectangular_model_abaqus.inp','wt');    

%% Main geometry
fprintf(fid,['********************************** \n']);
fprintf(fid,['** NODES AND GEOMETRY \n']);
fprintf(fid,['********************************** \n']);

%GIRDER nodes
formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** GIRDER NODES \n']);
fprintf(fid,[ '*NODE,NSET=GIRDERNODES \n']);
fprintf(fid,formatSpec, node_girder'); %print node number and coordinates
sprintf(formatSpec, node_girder') %print in matlab window

%END PIPE nodes
formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** END PIPE 1 NODES \n']);
fprintf(fid,[ '*NODE,NSET=ENDPIPE1NODES \n']);
fprintf(fid,formatSpec, node_endpipe1'); %print node number and coordinates
sprintf(formatSpec, node_endpipe1') %print in matlab window

formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** END PIPE 2 NODES \n']);
fprintf(fid,[ '*NODE,NSET=ENDPIPE2NODES \n']);
fprintf(fid,formatSpec, node_endpipe2'); %print node number and coordinates
sprintf(formatSpec, node_endpipe2') %print in matlab window

%GIRDER elements
fprintf(fid,['** \n']);
fprintf(fid,['**GIRDER ELEMENTS \n']);
fprintf(fid,[ '*ELEMENT, TYPE=' 'B31' ', ELSET='  'GIRDERELEMENTS' '\n']);
formatSpec = '%.0f, %.0f, %.0f \n'; %all three integer
fprintf(fid,formatSpec, elGirder');%print element number
sprintf(formatSpec, elGirder') %print in matlab window

%END PIPE elements
fprintf(fid,['** \n']);
fprintf(fid,['**END PIPE ELEMENTS \n']);
fprintf(fid,[ '*ELEMENT, TYPE=' 'B31' ', ELSET='  'ENDPIPEELEMENTS' '\n']);
formatSpec = '%.0f, %.0f, %.0f \n'; %all three integer
fprintf(fid,formatSpec, elEndpipe1');%print element number
sprintf(formatSpec, elEndpipe1') %print in matlab window
fprintf(fid,formatSpec, elEndpipe2');%print element number
sprintf(formatSpec, elEndpipe2') %print in matlab window

%Create section for GIRDER
fprintf(fid,['**\n']);
fprintf(fid,['**GIRDER \n']);
fprintf(fid,[ '*BEAM GENERAL SECTION, ELSET=GIRDERELEMENTS, SECTION=GENERAL, DENSITY=0\n']);%Density Aluminium alloy 6061 (kg/m^3)
fprintf(fid,[ '0.030065, 3.377e-8, 0, 3.006e-7, 8.86e-8   \n']);  %A. Iy, Izy, Iz, It
fprintf(fid,[ '0,1,0  \n']);
fprintf(fid,[ '69e9, 27e9  \n']); %NB! Sjekk faktiske verdier for aktuell type aluminium!!

%Create inertia and mass per unit length:
%Add inertia to the GIRDER beam
fprintf(fid,['**ADD BEAM INERTIA \n']);
fprintf(fid,['*BEAM ADDED INERTIA \n']);
fprintf(fid,['2.28,0,0,0,1.00625e-3,2.50171e-2,-9.36e-13 \n']);%Mass per unit length,,,,I11,I22,I12

%Create section for END PIPE
fprintf(fid,['**\n']);
fprintf(fid,['**END PIPE \n']);
fprintf(fid,[ '*BEAM GENERAL SECTION, ELSET=ENDPIPEELEMENTS, SECTION=GENERAL, DENSITY=2775\n']);%Density Aluminium alloy 6061 (kg/m^3)
fprintf(fid,[ '1.225e-4, 2.331e-8, 0, 2.331e-8, 4.659e-8   \n']);  %A. Iy, Izy, Iz, It
fprintf(fid,[ '0,1,0  \n']);
fprintf(fid,[ '69e9, 27e9  \n']); %NB! Sjekk faktiske verdier for aktuell type aluminium!!

%Create static step 1:
fprintf(fid,['**\n']);
fprintf(fid,['**Static step 1: Only gravity load on GIRDER. \n']);
fprintf(fid,['*STEP, AMPLITUDE=RAMP, NLGEOM, INC=5000 \n']);
fprintf(fid,[ '*STATIC  \n']);
fprintf(fid,[ '0.001, 1, 1e-8    \n']);

%Create load
fprintf(fid,[ '*DLOAD,OP=NEW \n']);
fprintf(fid,[ 'GIRDERELEMENTS, GRAV, 9.81, 0 , 0 , -1  \n']);

%Create BC's
fprintf(fid,[ '*BOUNDARY,OP=NEW  \n']);
fprintf(fid,[ '1,1,6,0   \n']);
fprintf(fid,[ '2,1,6,0   \n']);

%End step
fprintf(fid,[ '**    \n']);
fprintf(fid,[ '**   \n']);
fprintf(fid,[ '*END STEP   \n']);

%Step 3: Frequency step
fprintf(fid,['**\n']);
fprintf(fid,['**Step 4: Frequency step. \n']);
fprintf(fid,['*STEP, AMPLITUDE=RAMP, INC=5000 \n']);
fprintf(fid,[ '*FREQUENCY, NORMALIZATION=DISPLACEMENT  \n']);
fprintf(fid,[ ',,200  \n']); %Analysis up to 200Hz

%Create BC's
fprintf(fid,[ '*BOUNDARY,OP=NEW  \n']);
fprintf(fid,[ '1,1,4,0   \n']);
fprintf(fid,[ '2,2,4,0   \n']);

fprintf(fid,[ '*OUTPUT, FIELD   \n']);
fprintf(fid,[ '*Node output   \n']);
fprintf(fid,[ 'U, UR   \n']);

%End step
fprintf(fid,[ '**    \n']);
fprintf(fid,[ '**   \n']);
fprintf(fid,[ '*END STEP   \n']);
% 
% Create static step 2: Concentrated load on midpoint of girder

%Find midpoint node
midnode=node_girder(round(length(node_girder)/2),1);
%Define node set for midpoint node
fprintf(fid,['*NSET, NSET=MIDNODE \n']);
fprintf(fid,formatSpec, midnode');%print element number
fprintf(fid,[ '\n']);

fprintf(fid,['**\n']);
fprintf(fid,['**Static step 1: Concentrated load on GIRDER. \n']);
fprintf(fid,['*STEP, AMPLITUDE=RAMP, NLGEOM, INC=5000 \n']);
fprintf(fid,[ '*STATIC  \n']);
fprintf(fid,[ '0.001, 1, 1e-8    \n']);

%Create load
fprintf(fid,[ '*CLOAD,OP=NEW \n']);
fprintf(fid,['MIDNODE,3,-100  \n']);

% %Create BC's
% fprintf(fid,[ '*BOUNDARY,OP=NEW  \n']);
% fprintf(fid,[ '1,1,4,0   \n']);
% fprintf(fid,[ '2,2,4,0   \n']);

%Outputs
fprintf(fid,[ '*OUTPUT, FIELD  \n']);
fprintf(fid,[ '*Node Output \n']);
fprintf(fid,[ 'RF, U, UR \n']);
% 
fprintf(fid,[ '*OUTPUT, FIELD   \n']);
fprintf(fid,[ '*Element Output  \n']);
fprintf(fid,[ 'SF  \n']);

%Print displacement
fprintf(fid,[ '*NODE PRINT, NSET=MIDNODE, FREQUENCY=1, SUMMARY=NO   \n']);
fprintf(fid,[ 'U3 \n']);
fprintf(fid,[ 'CF3 \n']);

%End step
fprintf(fid,[ '**    \n']);
fprintf(fid,[ '**   \n']);
fprintf(fid,[ '*END STEP   \n']);


%% Run analysis
clc
JobName='Rectangular_Model'
system(['abaqus job=' JobName ' input=rectangular_model_abaqus interactive'])

pause(2)

winopen([ JobName '.odb']);
    